==> keycloak-parent-19.0.0-source-release.zip: keycloak-parent-19.0.0/model/map-jpa/src/main/java/org/keycloak/models/map/storage/jpa/authorization/policy/entity/JpaPolicyConfigEntity.java <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.keycloak.models.map.storage.jpa.authorization.policy.entity;

import java.util.Objects;
import javax.persistence.Entity;
import javax.persistence.Table;
import org.keycloak.models.map.storage.jpa.JpaAttributeEntity;

@Entity
@Table(name = "kc_authz_policy_config")
public class JpaPolicyConfigEntity extends JpaAttributeEntity<JpaPolicyEntity> {

    public JpaPolicyConfigEntity() {
    }

    public JpaPolicyConfigEntity(JpaPolicyEntity root, String name, String value) {
        super(root, name, value);
    }

    @Override
    public int hashCode() {
        return getClass().hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (!(obj instanceof JpaPolicyConfigEntity)) return false;
        JpaPolicyConfigEntity that = (JpaPolicyConfigEntity) obj;
        return Objects.equals(getParent(), that.getParent()) &&
               Objects.equals(getName(), that.getName());
    }
}

==> keycloak-parent-22.0.5-source-release.zip: keycloak-parent-22.0.5/model/map-jpa/src/main/java/org/keycloak/models/map/storage/jpa/authorization/policy/entity/JpaPolicyConfigEntity.java <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.keycloak.models.map.storage.jpa.authorization.policy.entity;

import java.util.Objects;
import jakarta.persistence.Entity;
import jakarta.persistence.Table;
import org.keycloak.models.map.storage.jpa.JpaAttributeEntity;

@Entity
@Table(name = "kc_authz_policy_config")
public class JpaPolicyConfigEntity extends JpaAttributeEntity<JpaPolicyEntity> {

    public JpaPolicyConfigEntity() {
    }

    public JpaPolicyConfigEntity(JpaPolicyEntity root, String name, String value) {
        super(root, name, value);
    }

    @Override
    public int hashCode() {
        return getClass().hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (!(obj instanceof JpaPolicyConfigEntity)) return false;
        JpaPolicyConfigEntity that = (JpaPolicyConfigEntity) obj;
        return Objects.equals(getParent(), that.getParent()) &&
               Objects.equals(getName(), that.getName());
    }
}
